Package: CNORode
Type: Package
Title: ODE add-on to CellNOptR
Version: 1.52.0
Date: 2022-03-22
Authors@R: c(
	person(given = "David",
           family = "Henriques",
           role = "aut"),
    person(given = "Thomas",
           family = "Cokelaer",
           role = c("aut")),
    person(given = "Federica",
           family = "Eduati",
           role = "ctb"),
    person(given = "Enio",
           family = "Gjerga",
           role = "ctb"),
    person(given = "Attila",
           family = "Gabor",
           role = "cre",
           email = "attila.gabor@uni-heidelberg.de")
           )
Author: David Henriques, Thomas Cokelaer, Attila Gabor, Federica Eduati, Enio Gjerga
Description: Logic based ordinary differential equation (ODE) add-on to
    CellNOptR.
License: GPL-2
LazyLoad: yes
Depends: CellNOptR, genalg
Enhances: doParallel, foreach
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
biocViews: ImmunoOncology, CellBasedAssays, CellBiology, Proteomics,
        Bioinformatics, TimeCourse
RoxygenNote: 7.1.2
git_url: https://git.bioconductor.org/packages/CNORode
git_branch: RELEASE_3_22
git_last_commit: 0bfa1d4
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 03:12:32 UTC; biocbuild
Maintainer: Attila Gabor <attila.gabor@uni-heidelberg.de>
